# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added

### Changed

### Deprecated

### Removed

### Fixed

### Security

## [v0.0.2] - 2025-07-16

### Fixed

- README now included in package

## [v0.0.1] - 2025-07-16

Initial release 🎉

[unreleased]: https://github.com/jkeifer/zarrzipan/compare/v0.0.2...HEAD
[v0.0.2]: https://github.com/jkeifer/zarrzipan/compare/v0.0.1...v0.0.1
[v0.0.1]: https://github.com/jkeifer/zarrzipan/releases/tag/v0.0.1
